Coverage for src/ramses_cli/__init__.py: 67%

1#!/usr/bin/env python3

2"""A CLI for the ramses_rf library."""

3

4 from __future__ import annotations

5

6 from typing import Final

7

8#

9# NOTE: All debug flags should be False for deployment to end-users

10 _DBG_FORCE_CLI_DEBUGGING: Final[bool] = (

11 False # for debugging of CLI (usu. for click debugging)

12)

13

14

15 if _DBG_FORCE_CLI_DEBUGGING:

16 from .debug import start_debugging

17

18 start_debugging(True)